pub struct DSymmetricEigen3 {
pub eigenvalues: DVec3,
pub eigenvectors: DMat3,
}Expand description
The eigen decomposition of a symmetric 3x3 matrix (f64 precision).
Fields
eigenvalues: DVec3The eigenvalues of the symmetric 3x3 matrix.
eigenvectors: DMat3The three eigenvectors of the symmetric 3x3 matrix (as columns).
Implementations
Sourceimpl DSymmetricEigen3
impl DSymmetricEigen3
Sourcepub fn new(mat: DMat3) -> Self
pub fn new(mat: DMat3) -> Self
Computes the eigen decomposition of the given symmetric 3x3 matrix.
The eigenvalues are returned in ascending order eigen1 < eigen2 < eigen3.
This can be reversed with the reverse method.
Sourcepub fn reverse(&self) -> Self
pub fn reverse(&self) -> Self
Reverses the order of the eigenvalues and their corresponding eigenvectors.
Sourcepub fn eigenvalues(mat: DMat3) -> DVec3
pub fn eigenvalues(mat: DMat3) -> DVec3
Computes the eigenvalues of a symmetric 3x3 matrix.
Reference: https://en.wikipedia.org/wiki/Eigenvalue_algorithm#3%C3%973_matrices
Sourcepub fn eigenvector1(mat: DMat3, eigenvalue1: f64) -> DVec3
pub fn eigenvector1(mat: DMat3, eigenvalue1: f64) -> DVec3
Computes the unit-length eigenvector corresponding to the eigenvalue1 of mat that was
computed from the root of a cubic polynomial with a multiplicity of 1.
If the other two eigenvalues are well separated, this method can be used for computing
all three eigenvectors. However, to avoid numerical issues when eigenvalues are close to
each other, it’s recommended to use the eigenvector2 method for the second eigenvector.
The third eigenvector can be computed as the cross product of the first two.
Sourcepub fn eigenvector2(mat: DMat3, eigenvector1: DVec3, eigenvalue2: f64) -> DVec3
pub fn eigenvector2(mat: DMat3, eigenvector1: DVec3, eigenvalue2: f64) -> DVec3
Computes the unit-length eigenvector corresponding to the eigenvalue2 of mat that was
computed from the root of a cubic polynomial with a potential multiplicity of 2.
The third eigenvector can be computed as the cross product of the first two.
Sourcepub fn eigenvector3(eigenvector1: DVec3, eigenvector2: DVec3) -> DVec3
pub fn eigenvector3(eigenvector1: DVec3, eigenvector2: DVec3) -> DVec3
Computes the third eigenvector as the cross product of the first two. If the given eigenvectors are valid, the returned vector should be unit length.