SymmetricEigen2

Struct SymmetricEigen2 

pub struct SymmetricEigen2 {
    pub eigenvalues: Vec2,
    pub eigenvectors: Mat2,
}
The eigen decomposition of a symmetric 2x2 matrix (f32 precision).

Fields

eigenvalues: Vec2

The eigenvalues of the symmetric 2x2 matrix.

eigenvectors: Mat2

The two eigenvectors of the symmetric 2x2 matrix (as columns).

Implementations

Source

impl SymmetricEigen2

pub fn new(mat: Mat2) -> Self

Computes the eigen decomposition of the given symmetric 2x2 matrix.

The eigenvalues are returned in descending order eigen1 > eigen2. This can be reversed with the reverse method.

pub fn reverse(&self) -> Self

Reverses the order of the eigenvalues and their corresponding eigenvectors.

pub fn eigenvalues(mat: Mat2) -> Vec2

Computes the eigenvalues of a symmetric 2x2 matrix.

Reference: https://croninprojects.org/Vince/Geodesy/FindingEigenvectors.pdf

pub fn eigenvector(mat: Mat2, eigenvalue: f32) -> Vec2

Computes the unit-length eigenvector corresponding to the given eigenvalue of the symmetric 2x2 mat.

Reference: https://croninprojects.org/Vince/Geodesy/FindingEigenvectors.pdf