pub struct SymmetricEigen3A {
pub eigenvalues: Vec3A,
pub eigenvectors: Mat3A,
}Expand description
The eigen decomposition of a symmetric 3x3 matrix (f32 precision).
Fields
eigenvalues: Vec3AThe eigenvalues of the symmetric 3x3 matrix.
eigenvectors: Mat3AThe three eigenvectors of the symmetric 3x3 matrix (as columns).
Implementations
Sourceimpl SymmetricEigen3A
impl SymmetricEigen3A
Sourcepub fn new(mat: Mat3A) -> Self
pub fn new(mat: Mat3A) -> Self
Computes the eigen decomposition of the given symmetric 3x3 matrix.
The eigenvalues are returned in ascending order eigen1 < eigen2 < eigen3.
This can be reversed with the reverse method.
Sourcepub fn reverse(&self) -> Self
pub fn reverse(&self) -> Self
Reverses the order of the eigenvalues and their corresponding eigenvectors.
Sourcepub fn eigenvalues(mat: Mat3A) -> Vec3A
pub fn eigenvalues(mat: Mat3A) -> Vec3A
Computes the eigenvalues of a symmetric 3x3 matrix.
Reference: https://en.wikipedia.org/wiki/Eigenvalue_algorithm#3%C3%973_matrices
Sourcepub fn eigenvector1(mat: Mat3A, eigenvalue1: f32) -> Vec3A
pub fn eigenvector1(mat: Mat3A, eigenvalue1: f32) -> Vec3A
Computes the unit-length eigenvector corresponding to the eigenvalue1 of mat that was
computed from the root of a cubic polynomial with a multiplicity of 1.
If the other two eigenvalues are well separated, this method can be used for computing
all three eigenvectors. However, to avoid numerical issues when eigenvalues are close to
each other, it’s recommended to use the eigenvector2 method for the second eigenvector.
The third eigenvector can be computed as the cross product of the first two.
Sourcepub fn eigenvector2(mat: Mat3A, eigenvector1: Vec3A, eigenvalue2: f32) -> Vec3A
pub fn eigenvector2(mat: Mat3A, eigenvector1: Vec3A, eigenvalue2: f32) -> Vec3A
Computes the unit-length eigenvector corresponding to the eigenvalue2 of mat that was
computed from the root of a cubic polynomial with a potential multiplicity of 2.
The third eigenvector can be computed as the cross product of the first two.
Sourcepub fn eigenvector3(eigenvector1: Vec3A, eigenvector2: Vec3A) -> Vec3A
pub fn eigenvector3(eigenvector1: Vec3A, eigenvector2: Vec3A) -> Vec3A
Computes the third eigenvector as the cross product of the first two. If the given eigenvectors are valid, the returned vector should be unit length.